@@ -165,6 +165,9 @@ class SlappResponseObject:
         """
         current_best = None
         for placement in self.get_low_ink_placements(p):
+            if not placement:
+                continue
+
             if current_best is None:
                 current_best = (placement[0], placement[1], placement[2])
             else:
@@ -190,4 +193,4 @@ class SlappResponseObject:
 
     @staticmethod
     def placement_is_winning_low_ink(placement: Tuple[int, str, str]):
-        return placement[0] == 1 and (placement[1].startswith("Top Cut") or placement[1].startswith("Alpha"))
+        return placement and placement[0] == 1 and (placement[1].startswith("Top Cut") or placement[1].startswith("Alpha"))
